==> kubernetes-model-admissionregistration-6.6.0-sources.jar: io/fabric8/kubernetes/api/model/admissionregistration/v1alpha1/ValidatingAdmissionPolicySpecFluent.java <==
package io.fabric8.kubernetes.api.model.admissionregistration.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.List;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.lang.Integer;
import java.util.Collection;
import java.lang.Object;
import java.util.Map;

 /**
  * Generated
  */
public interface ValidatingAdmissionPolicySpecFluent<A extends ValidatingAdmissionPolicySpecFluent<A>> extends Fluent<A>{
  public String getFailurePolicy();
  public A withFailurePolicy(String failurePolicy);
  public Boolean hasFailurePolicy();
  
  /**
   * This method has been deprecated, please use method buildMatchConstraints instead.
   * @return The buildable object.
   */
  @Deprecated
  public MatchResources getMatchConstraints();
  public MatchResources buildMatchConstraints();
  public A withMatchConstraints(MatchResources matchConstraints);
  public Boolean hasMatchConstraints();
  public ValidatingAdmissionPolicySpecFluent.MatchConstraintsNested<A> withNewMatchConstraints();
  public ValidatingAdmissionPolicySpecFluent.MatchConstraintsNested<A> withNewMatchConstraintsLike(MatchResources item);
  public ValidatingAdmissionPolicySpecFluent.MatchConstraintsNested<A> editMatchConstraints();
  public ValidatingAdmissionPolicySpecFluent.MatchConstraintsNested<A> editOrNewMatchConstraints();
  public ValidatingAdmissionPolicySpecFluent.MatchConstraintsNested<A> editOrNewMatchConstraintsLike(MatchResources item);
  
  /**
   * This method has been deprecated, please use method buildParamKind instead.
   * @return The buildable object.
   */
  @Deprecated
  public ParamKind getParamKind();
  public ParamKind buildParamKind();
  public A withParamKind(ParamKind paramKind);
  public Boolean hasParamKind();
  public A withNewParamKind(String apiVersion,String kind);
  public ValidatingAdmissionPolicySpecFluent.ParamKindNested<A> withNewParamKind();
  public ValidatingAdmissionPolicySpecFluent.ParamKindNested<A> withNewParamKindLike(ParamKind item);
  public ValidatingAdmissionPolicySpecFluent.ParamKindNested<A> editParamKind();
  public ValidatingAdmissionPolicySpecFluent.ParamKindNested<A> editOrNewParamKind();
  public ValidatingAdmissionPolicySpecFluent.ParamKindNested<A> editOrNewParamKindLike(ParamKind item);
  public A addToValidations(Integer index,Validation item);
  public A setToValidations(Integer index,Validation item);
  public A addToValidations(io.fabric8.kubernetes.api.model.admissionregistration.v1alpha1.Validation... items);
  public A addAllToValidations(Collection<Validation> items);
  public A removeFromValidations(io.fabric8.kubernetes.api.model.admissionregistration.v1alpha1.Validation... items);
  public A removeAllFromValidations(Collection<Validation> items);
  public A removeMatchingFromValidations(Predicate<ValidationBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildValidations instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<Validation> getValidations();
  public List<Validation> buildValidations();
  public Validation buildValidation(Integer index);
  public Validation buildFirstValidation();
  public Validation buildLastValidation();
  public Validation buildMatchingValidation(Predicate<ValidationBuilder> predicate);
  public Boolean hasMatchingValidation(Predicate<ValidationBuilder> predicate);
  public A withValidations(List<Validation> validations);
  public A withValidations(io.fabric8.kubernetes.api.model.admissionregistration.v1alpha1.Validation... validations);
  public Boolean hasValidations();
  public A addNewValidation(String expression,String message,String reason);
  public ValidatingAdmissionPolicySpecFluent.ValidationsNested<A> addNewValidation();
  public ValidatingAdmissionPolicySpecFluent.ValidationsNested<A> addNewValidationLike(Validation item);
  public ValidatingAdmissionPolicySpecFluent.ValidationsNested<A> setNewValidationLike(Integer index,Validation item);
  public ValidatingAdmissionPolicySpecFluent.ValidationsNested<A> editValidation(Integer index);
  public ValidatingAdmissionPolicySpecFluent.ValidationsNested<A> editFirstValidation();
  public ValidatingAdmissionPolicySpecFluent.ValidationsNested<A> editLastValidation();
  public ValidatingAdmissionPolicySpecFluent.ValidationsNested<A> editMatchingValidation(Predicate<ValidationBuilder> predicate);
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface MatchConstraintsNested<N> extends Nested<N>,MatchResourcesFluent<ValidatingAdmissionPolicySpecFluent.MatchConstraintsNested<N>>{
    public N and();
    public N endMatchConstraints();
    
  }
  public interface ParamKindNested<N> extends Nested<N>,ParamKindFluent<ValidatingAdmissionPolicySpecFluent.ParamKindNested<N>>{
    public N and();
    public N endParamKind();
    
  }
  public interface ValidationsNested<N> extends Nested<N>,ValidationFluent<ValidatingAdmissionPolicySpecFluent.ValidationsNested<N>>{
    public N and();
    public N endValidation();
    
  }
  
}

==> kubernetes-model-admissionregistration-6.7.2-sources.jar: io/fabric8/kubernetes/api/model/admissionregistration/v1alpha1/ValidatingAdmissionPolicySpecFluent.java <==
package io.fabric8.kubernetes.api.model.admissionregistration.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.List;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.util.Collection;
import java.lang.Object;
import java.util.Map;

 /**
  * Generated
  */
public interface ValidatingAdmissionPolicySpecFluent<A extends ValidatingAdmissionPolicySpecFluent<A>> extends Fluent<A>{
  public String getFailurePolicy();
  public A withFailurePolicy(String failurePolicy);
  public Boolean hasFailurePolicy();
  
  /**
   * This method has been deprecated, please use method buildMatchConstraints instead.
   * @return The buildable object.
   */
  @Deprecated
  public MatchResources getMatchConstraints();
  public MatchResources buildMatchConstraints();
  public A withMatchConstraints(MatchResources matchConstraints);
  public Boolean hasMatchConstraints();
  public ValidatingAdmissionPolicySpecFluent.MatchConstraintsNested<A> withNewMatchConstraints();
  public ValidatingAdmissionPolicySpecFluent.MatchConstraintsNested<A> withNewMatchConstraintsLike(MatchResources item);
  public ValidatingAdmissionPolicySpecFluent.MatchConstraintsNested<A> editMatchConstraints();
  public ValidatingAdmissionPolicySpecFluent.MatchConstraintsNested<A> editOrNewMatchConstraints();
  public ValidatingAdmissionPolicySpecFluent.MatchConstraintsNested<A> editOrNewMatchConstraintsLike(MatchResources item);
  
  /**
   * This method has been deprecated, please use method buildParamKind instead.
   * @return The buildable object.
   */
  @Deprecated
  public ParamKind getParamKind();
  public ParamKind buildParamKind();
  public A withParamKind(ParamKind paramKind);
  public Boolean hasParamKind();
  public A withNewParamKind(String apiVersion,String kind);
  public ValidatingAdmissionPolicySpecFluent.ParamKindNested<A> withNewParamKind();
  public ValidatingAdmissionPolicySpecFluent.ParamKindNested<A> withNewParamKindLike(ParamKind item);
  public ValidatingAdmissionPolicySpecFluent.ParamKindNested<A> editParamKind();
  public ValidatingAdmissionPolicySpecFluent.ParamKindNested<A> editOrNewParamKind();
  public ValidatingAdmissionPolicySpecFluent.ParamKindNested<A> editOrNewParamKindLike(ParamKind item);
  public A addToValidations(int index,Validation item);
  public A setToValidations(int index,Validation item);
  public A addToValidations(io.fabric8.kubernetes.api.model.admissionregistration.v1alpha1.Validation... items);
  public A addAllToValidations(Collection<Validation> items);
  public A removeFromValidations(io.fabric8.kubernetes.api.model.admissionregistration.v1alpha1.Validation... items);
  public A removeAllFromValidations(Collection<Validation> items);
  public A removeMatchingFromValidations(Predicate<ValidationBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildValidations instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<Validation> getValidations();
  public List<Validation> buildValidations();
  public Validation buildValidation(int index);
  public Validation buildFirstValidation();
  public Validation buildLastValidation();
  public Validation buildMatchingValidation(Predicate<ValidationBuilder> predicate);
  public Boolean hasMatchingValidation(Predicate<ValidationBuilder> predicate);
  public A withValidations(List<Validation> validations);
  public A withValidations(io.fabric8.kubernetes.api.model.admissionregistration.v1alpha1.Validation... validations);
  public Boolean hasValidations();
  public A addNewValidation(String expression,String message,String reason);
  public ValidatingAdmissionPolicySpecFluent.ValidationsNested<A> addNewValidation();
  public ValidatingAdmissionPolicySpecFluent.ValidationsNested<A> addNewValidationLike(Validation item);
  public ValidatingAdmissionPolicySpecFluent.ValidationsNested<A> setNewValidationLike(int index,Validation item);
  public ValidatingAdmissionPolicySpecFluent.ValidationsNested<A> editValidation(int index);
  public ValidatingAdmissionPolicySpecFluent.ValidationsNested<A> editFirstValidation();
  public ValidatingAdmissionPolicySpecFluent.ValidationsNested<A> editLastValidation();
  public ValidatingAdmissionPolicySpecFluent.ValidationsNested<A> editMatchingValidation(Predicate<ValidationBuilder> predicate);
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface MatchConstraintsNested<N> extends Nested<N>,MatchResourcesFluent<ValidatingAdmissionPolicySpecFluent.MatchConstraintsNested<N>>{
    public N and();
    public N endMatchConstraints();
    
  }
  public interface ParamKindNested<N> extends Nested<N>,ParamKindFluent<ValidatingAdmissionPolicySpecFluent.ParamKindNested<N>>{
    public N and();
    public N endParamKind();
    
  }
  public interface ValidationsNested<N> extends Nested<N>,ValidationFluent<ValidatingAdmissionPolicySpecFluent.ValidationsNested<N>>{
    public N and();
    public N endValidation();
    
  }
  
}
